bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.add_plate_axis
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.add_plate_axis